using System;
using System.Net;
using System.IO;
using Bespoke.Common.Osc;

namespace Receiver
{
	class Program
	{
		static void Main(string[] args)
		{
            sOscServer = new OscServer(TransportType.Udp, IPAddress.Loopback, ServerPort, ServerAddress, Bespoke.Common.Net.TransmissionType.Multicast);
			sOscServer.RegisterMethod(AliveMethod);
            sOscServer.RegisterMethod("/another/test/message");
            sOscServer.BundleReceived += new OscBundleReceivedHandler(sOscServer_BundleReceived);
			sOscServer.MessageReceived += new OscMessageReceivedHandler(sOscServer_MessageReceived);

			sOscServer.Start();

			Console.WriteLine("OSC Receiver: " + sOscServer.TransmissionType.ToString());
			Console.WriteLine("Press any key to exit.");
			Console.ReadKey();
			sOscServer.Stop();
		}

        static void sOscServer_BundleReceived(object sender, OscBundleReceivedEventArgs e)
        {
            Console.WriteLine(string.Format("\nBundle Received [{0}]: {1} Message Count: {2}", e.Bundle.SourceEndPoint.Address, e.Bundle.Address, e.Bundle.Messages.Length));
        }

		static void sOscServer_MessageReceived(object sender, OscMessageReceivedEventArgs e)
		{
            Console.WriteLine(string.Format("Message Received [{0}]: {1}", e.Message.SourceEndPoint.Address, e.Message.Address));
		}

        private static readonly IPAddress ServerAddress = IPAddress.Parse("224.25.26.27");
		private static readonly int ServerPort = 5103;
		private static readonly string AliveMethod = "/osctest/alive";

		private static OscServer sOscServer;
	}
}
